@@ -58,50 +58,90 @@ pub enum DisplaySafeUrlError {
 #[repr(transparent)]
 pub struct DisplaySafeUrl(Url);
 
+/// Check if a path or fragment contains a credential-like pattern (`:` followed by `@`).
+///
+/// This skips colons that are followed by `//`, as those indicate URL schemes (e.g., `https://`)
+/// rather than credentials. This is important for handling nested URLs like proxy URLs:
+/// `git+https://proxy.com/https://github.com/user/repo.git@branch`.
+fn has_credential_like_pattern(s: &str) -> bool {
+    let mut remaining = s;
+    while let Some(colon_pos) = remaining.find(':') {
+        let after_colon = &remaining[colon_pos + 1..];
+        // If the colon is followed by "//", consider it a URL scheme.
+        if after_colon.starts_with("//") {
+            remaining = after_colon;
+            continue;
+        }
+        // Check if there's an @ after this colon.
+        if after_colon.contains('@') {
+            return true;
+        }
+        remaining = after_colon;
+    }
+    false
+}
+
 impl DisplaySafeUrl {
     #[inline]
     pub fn parse(input: &str) -> Result<Self, DisplaySafeUrlError> {
         let url = Url::parse(input)?;
 
-        // Reject some ambiguous cases, e.g., `https://user/name:password@domain/a/b/c`
-        //
-        // In this case the user *probably* meant to have a username of "user/name", but both RFC
-        // 3986 and WHATWG URL expect the userinfo (RFC 3986) or authority (WHATWG) to not contain a
-        // non-percent-encoded slash or other special character.
-        //
-        // This ends up being moderately annoying to detect, since the above gets parsed into a
-        // "valid" WHATWG URL where the host is `used` and the pathname is
-        // `/name:password@domain/a/b/c` rather than causing a parse error.
-        //
-        // To detect it, we use a heuristic: if the password component is missing but the path or
-        // fragment contain a `:` followed by a `@`, then we assume the URL is ambiguous.
-        if url.password().is_none()
-            && (url
-                .path()
-                .find(':')
-                .is_some_and(|pos| url.path()[pos..].contains('@'))
-                || url
-                    .fragment()
-                    .map(|fragment| {
-                        fragment
-                            .find(':')
-                            .is_some_and(|pos| fragment[pos..].contains('@'))
-                    })
-                    .unwrap_or(false))
-            // If the above is true, we should always expect to find these in the given URL
-            && let Some(col_pos) = input.find(':')
-            && let Some(at_pos) = input.rfind('@')
-        {
-            // Our ambiguous URL probably has credentials in it, so we don't want to blast it out in
-            // the error message. We somewhat aggressively replace everything between the scheme's
-            // ':' and the lastmost `@` with `***`.
-            let redacted_path = format!("{}***{}", &input[0..=col_pos], &input[at_pos..]);
-            return Err(DisplaySafeUrlError::AmbiguousAuthority(redacted_path));
-        }
+        Self::reject_ambiguous_credentials(input, &url)?;
 
         Ok(Self(url))
     }
 
+    /// Reject some ambiguous cases, e.g., `https://user/name:password@domain/a/b/c`
+    ///
+    /// In this case the user *probably* meant to have a username of "user/name", but both RFC
+    /// 3986 and WHATWG URL expect the userinfo (RFC 3986) or authority (WHATWG) to not contain a
+    /// non-percent-encoded slash or other special character.
+    ///
+    /// This ends up being moderately annoying to detect, since the above gets parsed into a
+    /// "valid" WHATWG URL where the host is `used` and the pathname is
+    /// `/name:password@domain/a/b/c` rather than causing a parse error.
+    ///
+    /// To detect it, we use a heuristic: if the password component is missing but the path or
+    /// fragment contain a `:` followed by a `@`, then we assume the URL is ambiguous.
+    fn reject_ambiguous_credentials(input: &str, url: &Url) -> Result<(), DisplaySafeUrlError> {
+        // `git://`, `http://`, and `https://` URLs may carry credentials, while `file://` URLs
+        // on Windows may contain both sigils, but it's always safe, e.g.
+        // `file://C:/Users/ferris/project@home/workspace`.
+        if url.scheme() == "file" {
+            return Ok(());
+        }
+
+        if url.password().is_some() {
+            return Ok(());
+        }
+
+        // Check for the suspicious pattern.
+        if !has_credential_like_pattern(url.path())
+            && !url
+                .fragment()
+                .map(has_credential_like_pattern)
+                .unwrap_or(false)
+        {
+            return Ok(());
+        }
+
+        // If the previous check passed, we should always expect to find these in the given URL.
+        let (Some(col_pos), Some(at_pos)) = (input.find(':'), input.rfind('@')) else {
+            if cfg!(debug_assertions) {
+                unreachable!(
+                    "`:` or `@` sign missing in URL that was confirmed to contain them: {input}"
+                );
+            }
+            return Ok(());
+        };
+
+        // Our ambiguous URL probably has credentials in it, so we don't want to blast it out in
+        // the error message. We somewhat aggressively replace everything between the scheme's
+        // ':' and the lastmost `@` with `***`.
+        let redacted_path = format!("{}***{}", &input[0..=col_pos], &input[at_pos..]);
+        Err(DisplaySafeUrlError::AmbiguousAuthority(redacted_path))
+    }
+
     /// Create a new [`DisplaySafeUrl`] from a [`Url`].
     ///
     /// Unlike [`Self::parse`], this doesn't perform any ambiguity checks.
@@ -241,6 +281,12 @@ impl From<DisplaySafeUrl> for Url {
     }
 }
 
+impl From<Url> for DisplaySafeUrl {
+    fn from(url: Url) -> Self {
+        Self(url)
+    }
+}
+
 impl FromStr for DisplaySafeUrl {
     type Err = DisplaySafeUrlError;
 
@@ -453,4 +499,30 @@ mod tests {
             }
         }
     }
+
+    #[test]
+    fn parse_url_not_ambiguous() {
+        for url in &[
+            // https://github.com/astral-sh/uv/issues/16756
+            "file:///C:/jenkins/ython_Environment_Manager_PR-251@2/venv%201/workspace",
+            // https://github.com/astral-sh/uv/issues/17214
+            // Git proxy URLs with nested schemes should not trigger the ambiguity check
+            "git+https://githubproxy.cc/https://github.com/user/repo.git@branch",
+            "git+https://proxy.example.com/https://github.com/org/project@v1.0.0",
+            "git+https://proxy.example.com/https://github.com/org/project@refs/heads/main",
+        ] {
+            DisplaySafeUrl::parse(url).unwrap();
+        }
+    }
+
+    #[test]
+    fn credential_like_pattern() {
+        assert!(!has_credential_like_pattern(
+            "/https://github.com/user/repo.git@branch"
+        ));
+        assert!(!has_credential_like_pattern("/http://example.com/path@ref"));
+
+        assert!(has_credential_like_pattern("/name:password@domain/a/b/c"));
+        assert!(has_credential_like_pattern(":password@domain"));
+    }
 }
